==> npcpy-1.1.6.tar.gz: npcpy-1.1.6/tests/test_audio.py <==
import tempfile
import time
from npcpy.data.audio import (
    create_and_queue_audio, play_audio, process_text_for_tts,
    run_transcription, transcribe_recording
)


def test_process_text_for_tts():
    """Test text processing for TTS"""
    try:
        # Test basic text cleaning
        text = "Hello *world*! This is a [test] with {special} characters."
        processed = process_text_for_tts(text)
        
        assert isinstance(processed, str)
        assert "*" not in processed
        assert "[" not in processed
        assert "{" not in processed
        
        print(f"Original: {text}")
        print(f"Processed: {processed}")
        
    except Exception as e:
        print(f"Text processing test failed: {e}")


def test_process_text_for_tts_abbreviations():
    """Test text processing with abbreviations"""
    try:
        text = "Dr.Smith went to U.S.A. and met Mr.Johnson."
        processed = process_text_for_tts(text)
        
        assert isinstance(processed, str)
        print(f"Abbreviation processing: {text} -> {processed}")
        
    except Exception as e:
        print(f"Abbreviation processing test failed: {e}")


def test_create_and_queue_audio():
    """Test audio creation and queueing"""
    try:
        state = {
            "tts_is_speaking": False,
            "running": True
        }
        
        text = "This is a test message for audio generation."
        
        # This will likely fail without proper TTS setup, but tests the function flow
        create_and_queue_audio(text, state)
        
        print("Audio creation test completed (may have failed due to TTS dependencies)")
        
    except Exception as e:
        print(f"Audio creation test failed (expected without TTS setup): {e}")


def test_play_audio():
    """Test audio playback"""
    try:
        # Create a temporary audio file for testing
        temp_dir = tempfile.mkdtemp()
        temp_audio = f"{temp_dir}/test_audio.wav"
        
        # Create a minimal WAV file (this is a very basic example)
        # In practice, you'd need a real audio file
        
        state = {
            "tts_is_speaking": False,
            "running": True
        }
        
        # This will fail without a real audio file, but tests the function
        try:
            play_audio(temp_audio, state)
        except Exception:
            print("Play audio test failed as expected (no real audio file)")
        
    except Exception as e:
        print(f"Play audio test setup failed: {e}")
    finally:
        import shutil
        if 'temp_dir' in locals():
            shutil.rmtree(temp_dir)


def test_run_transcription():
    """Test audio transcription"""
    try:
        import numpy as np
        
        # Create dummy audio data (silence)
        audio_np = np.zeros(16000, dtype=np.float32)  # 1 second of silence at 16kHz
        
        # This will fail without proper whisper setup, but tests the function
        result = run_transcription(audio_np)
        
        if result:
            print(f"Transcription result: {result}")
        else:
            print("Transcription returned empty result")
        
    except Exception as e:
        print(f"Transcription test failed (expected without whisper setup): {e}")


def test_transcribe_recording():
    """Test recording transcription"""
    try:
        # Create fake audio data
        audio_data = [b"fake_audio_chunk_1", b"fake_audio_chunk_2"]
        
        # This will fail but tests the function flow
        result = transcribe_recording(audio_data)
        
        print(f"Recording transcription test completed: {result}")
        
    except Exception as e:
        print(f"Recording transcription test failed (expected): {e}")


def test_audio_state_management():
    """Test audio state management"""
    try:
        state = {
            "tts_is_speaking": False,
            "recording_data": [],
            "buffer_data": [],
            "is_recording": False,
            "last_speech_time": 0,
            "running": True
        }
        
        # Test state changes
        original_speaking = state["tts_is_speaking"]
        state["tts_is_speaking"] = True
        
        assert state["tts_is_speaking"] != original_speaking
        
        # Test recording state
        state["is_recording"] = True
        assert state["is_recording"] == True
        
        print("Audio state management test passed")
        
    except Exception as e:
        print(f"State management test failed: {e}")


def test_audio_dependencies():
    """Test audio dependencies availability"""
    dependencies = {
        'gtts': None,
        'pygame': None,
        'pyaudio': None,
        'faster_whisper': None,
        'numpy': None
    }
    
    for dep in dependencies:
        try:
            if dep == 'gtts':
                from gtts import gTTS
                dependencies[dep] = True
            elif dep == 'pygame':
                import pygame
                dependencies[dep] = True
            elif dep == 'pyaudio':
                import pyaudio
                dependencies[dep] = True
            elif dep == 'faster_whisper':
                from faster_whisper import WhisperModel
                dependencies[dep] = True
            elif dep == 'numpy':
                import numpy
                dependencies[dep] = True
        except ImportError:
            dependencies[dep] = False
    
    print("Audio dependencies status:")
    for dep, available in dependencies.items():
        status = "✓" if available else "✗"
        print(f"  {status} {dep}")
    
    available_count = sum(1 for available in dependencies.values() if available)
    print(f"Available: {available_count}/{len(dependencies)}")


def test_text_processing_edge_cases():
    """Test text processing edge cases"""
    try:
        test_cases = [
            "",  # Empty string
            "   ",  # Whitespace only
            "123.456.789",  # Numbers with dots
            "Hello... world!!!",  # Multiple punctuation
            "Mr. Dr. Mrs. Jr.",  # Multiple abbreviations
            "a.b.c.d.e.f.g",  # Lots of dots
        ]
        
        for test_text in test_cases:
            processed = process_text_for_tts(test_text)
            assert isinstance(processed, str)
            print(f"Edge case: '{test_text}' -> '{processed}'")
        
        print("Text processing edge cases passed")
        
    except Exception as e:
        print(f"Edge cases test failed: {e}")


def test_audio_format_constants():
    """Test audio format constants"""
    try:
        # These should be defined in the audio module
        from npcpy.data.audio import FORMAT, CHANNELS, RATE, CHUNK
        
        assert isinstance(FORMAT, int)
        assert isinstance(CHANNELS, int)
        assert isinstance(RATE, int)
        assert isinstance(CHUNK, int)
        
        assert CHANNELS > 0
        assert RATE > 0
        assert CHUNK > 0
        
        print(f"Audio constants: FORMAT={FORMAT}, CHANNELS={CHANNELS}, RATE={RATE}, CHUNK={CHUNK}")
        
    except ImportError:
        print("Audio constants not available (expected if audio dependencies not installed)")
    except Exception as e:
        print(f"Audio constants test failed: {e}")


def test_cleanup_functions():
    """Test audio cleanup functions"""
    try:
        from npcpy.data.audio import cleanup_temp_files, interrupt_speech
        
        # Test cleanup function
        cleanup_temp_files()
        print("Cleanup function called successfully")
        
        # Test interrupt function
        interrupt_speech()
        print("Interrupt function called successfully")
        
    except ImportError:
        print("Cleanup functions not available (expected if audio dependencies not installed)")
    except Exception as e:
        print(f"Cleanup functions test failed: {e}")

==> npcpy-1.2.4.4.tar.gz: npcpy-1.2.4.4/tests/test_audio.py <==
import tempfile
import time
from npcpy.data.audio import (
    create_and_queue_audio, play_audio, process_text_for_tts,
    run_transcription, transcribe_recording
)


def test_process_text_for_tts():
    """Test text processing for TTS"""
    try:
        
        text = "Hello *world*! This is a [test] with {special} characters."
        processed = process_text_for_tts(text)
        
        assert isinstance(processed, str)
        assert "*" not in processed
        assert "[" not in processed
        assert "{" not in processed
        
        print(f"Original: {text}")
        print(f"Processed: {processed}")
        
    except Exception as e:
        print(f"Text processing test failed: {e}")


def test_process_text_for_tts_abbreviations():
    """Test text processing with abbreviations"""
    try:
        text = "Dr.Smith went to U.S.A. and met Mr.Johnson."
        processed = process_text_for_tts(text)
        
        assert isinstance(processed, str)
        print(f"Abbreviation processing: {text} -> {processed}")
        
    except Exception as e:
        print(f"Abbreviation processing test failed: {e}")


def test_create_and_queue_audio():
    """Test audio creation and queueing"""
    try:
        state = {
            "tts_is_speaking": False,
            "running": True
        }
        
        text = "This is a test message for audio generation."
        
        
        create_and_queue_audio(text, state)
        
        print("Audio creation test completed (may have failed due to TTS dependencies)")
        
    except Exception as e:
        print(f"Audio creation test failed (expected without TTS setup): {e}")


def test_play_audio():
    """Test audio playback"""
    try:
        
        temp_dir = tempfile.mkdtemp()
        temp_audio = f"{temp_dir}/test_audio.wav"
        
        
        
        
        state = {
            "tts_is_speaking": False,
            "running": True
        }
        
        
        try:
            play_audio(temp_audio, state)
        except Exception:
            print("Play audio test failed as expected (no real audio file)")
        
    except Exception as e:
        print(f"Play audio test setup failed: {e}")
    finally:
        import shutil
        if 'temp_dir' in locals():
            shutil.rmtree(temp_dir)


def test_run_transcription():
    """Test audio transcription"""
    try:
        import numpy as np
        
        
        audio_np = np.zeros(16000, dtype=np.float32)  
        
        
        result = run_transcription(audio_np)
        
        if result:
            print(f"Transcription result: {result}")
        else:
            print("Transcription returned empty result")
        
    except Exception as e:
        print(f"Transcription test failed (expected without whisper setup): {e}")


def test_transcribe_recording():
    """Test recording transcription"""
    try:
        
        audio_data = [b"fake_audio_chunk_1", b"fake_audio_chunk_2"]
        
        
        result = transcribe_recording(audio_data)
        
        print(f"Recording transcription test completed: {result}")
        
    except Exception as e:
        print(f"Recording transcription test failed (expected): {e}")


def test_audio_state_management():
    """Test audio state management"""
    try:
        state = {
            "tts_is_speaking": False,
            "recording_data": [],
            "buffer_data": [],
            "is_recording": False,
            "last_speech_time": 0,
            "running": True
        }
        
        
        original_speaking = state["tts_is_speaking"]
        state["tts_is_speaking"] = True
        
        assert state["tts_is_speaking"] != original_speaking
        
        
        state["is_recording"] = True
        assert state["is_recording"] == True
        
        print("Audio state management test passed")
        
    except Exception as e:
        print(f"State management test failed: {e}")


def test_audio_dependencies():
    """Test audio dependencies availability"""
    dependencies = {
        'gtts': None,
        'pygame': None,
        'pyaudio': None,
        'faster_whisper': None,
        'numpy': None
    }
    
    for dep in dependencies:
        try:
            if dep == 'gtts':
                from gtts import gTTS
                dependencies[dep] = True
            elif dep == 'pygame':
                import pygame
                dependencies[dep] = True
            elif dep == 'pyaudio':
                import pyaudio
                dependencies[dep] = True
            elif dep == 'faster_whisper':
                from faster_whisper import WhisperModel
                dependencies[dep] = True
            elif dep == 'numpy':
                import numpy
                dependencies[dep] = True
        except ImportError:
            dependencies[dep] = False
    
    print("Audio dependencies status:")
    for dep, available in dependencies.items():
        status = "✓" if available else "✗"
        print(f"  {status} {dep}")
    
    available_count = sum(1 for available in dependencies.values() if available)
    print(f"Available: {available_count}/{len(dependencies)}")


def test_text_processing_edge_cases():
    """Test text processing edge cases"""
    try:
        test_cases = [
            "",  
            "   ",  
            "123.456.789",  
            "Hello... world!!!",  
            "Mr. Dr. Mrs. Jr.",  
            "a.b.c.d.e.f.g",  
        ]
        
        for test_text in test_cases:
            processed = process_text_for_tts(test_text)
            assert isinstance(processed, str)
            print(f"Edge case: '{test_text}' -> '{processed}'")
        
        print("Text processing edge cases passed")
        
    except Exception as e:
        print(f"Edge cases test failed: {e}")


def test_audio_format_constants():
    """Test audio format constants"""
    try:
        
        from npcpy.data.audio import FORMAT, CHANNELS, RATE, CHUNK
        
        assert isinstance(FORMAT, int)
        assert isinstance(CHANNELS, int)
        assert isinstance(RATE, int)
        assert isinstance(CHUNK, int)
        
        assert CHANNELS > 0
        assert RATE > 0
        assert CHUNK > 0
        
        print(f"Audio constants: FORMAT={FORMAT}, CHANNELS={CHANNELS}, RATE={RATE}, CHUNK={CHUNK}")
        
    except ImportError:
        print("Audio constants not available (expected if audio dependencies not installed)")
    except Exception as e:
        print(f"Audio constants test failed: {e}")


def test_cleanup_functions():
    """Test audio cleanup functions"""
    try:
        from npcpy.data.audio import cleanup_temp_files, interrupt_speech
        
        
        cleanup_temp_files()
        print("Cleanup function called successfully")
        
        
        interrupt_speech()
        print("Interrupt function called successfully")
        
    except ImportError:
        print("Cleanup functions not available (expected if audio dependencies not installed)")
    except Exception as e:
        print(f"Cleanup functions test failed: {e}")
